PALM-meteo: palmmeteo/logging.py File Reference

PALM-meteo

Namespaces | Functions | Variables
logging.py File Reference

## Namespaces
namespace | palmmeteo
namespace | palmmeteo.logging

## Functions
def | palmmeteo.logging.die (s, *args, **kwargs)
def | palmmeteo.logging.warn (s, *args, **kwargs)
def | palmmeteo.logging.log_on (s, *args, **kwargs)
def | palmmeteo.logging.log_off (s, *args, **kwargs)
def | palmmeteo.logging.configure_log (cfg)

## Variables
| palmmeteo.logging.log_output = sys.stdout.write
| palmmeteo.logging.error_output = sys.stderr.write
def | palmmeteo.logging.log = log_on
def | palmmeteo.logging.verbose = log_off